<?php
/**
 * roofers functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package roofers
 */


define('ROOFERS_THEMEROOT', get_template_directory_uri());
define('ROOFERS_THEMEINCLUDES', get_template_directory(). '/inc');


if ( ! function_exists( 'roofers_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function roofers_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on roofers, use a find and replace
	 * to change 'roofers' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'roofers', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	 /****** Thumbnails Generate********/
	 
	add_theme_support( 'title-tag' );
    add_theme_support( 'post-thumbnails' );
    add_image_size( 'roofers360x210', 360, 210,true );
    add_image_size( 'roofers75x75', 75, 75,true );
     add_image_size( 'roofers260x355', 260, 355,true );
    

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'roofers' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
    
	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'image',
	) );    
	/*---------	This theme styles the visual editor with editor-style.css to match the theme style ---------*/
	add_editor_style( array( 'css/editor-style.css', '' ) );
	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'roofers_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'roofers_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function roofers_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'roofers_content_width', 640 );
}
add_action( 'after_setup_theme', 'roofers_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function roofers_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar Left', 'roofers' ),
		'id'            => 'blog-sidebar-left',
		'description'   => esc_html__( 'Add widgets here.', 'roofers' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );	
    
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar Right', 'roofers' ),
		'id'            => 'blog-sidebar-right',
		'description'   => esc_html__( 'Add widgets here.', 'roofers' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );	
    
    register_sidebar( array(
		'name'          => esc_html__( 'Footer One', 'roofers' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'roofers' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title"> ',
		'after_title'   => '</h3> <div class="seperator"></div>',
	) );
    
      register_sidebar( array(
		'name'          => esc_html__( 'Footer Two', 'roofers' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'roofers' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title"> ',
		'after_title'   => '</h3> <div class="seperator"></div>',
	) );
    
      register_sidebar( array(
		'name'          => esc_html__( 'Footer Three', 'roofers' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'roofers' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title"> ',
		'after_title'   => '</h3> <div class="seperator"></div>',
	) );
      register_sidebar( array(
		'name'          => esc_html__( 'Custom Sidebar', 'roofers' ),
		'id'            => 'sidebar-custom',
		'description'   => esc_html__( 'Add widgets here.', 'roofers' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title"> ',
		'after_title'   => '</h3> <div class="seperator"></div>',
	) );
    
    
}
add_action( 'widgets_init', 'roofers_widgets_init' );


/**
 * Enqueue scripts and styles.
 */
function roofers_scripts() {
    
    require_once( ROOFERS_THEMEINCLUDES . '/enqueue_styles.php' ); 
    require_once( ROOFERS_THEMEINCLUDES . '/enqueue_scripts.php' );  


 if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
  wp_enqueue_script( 'comment-reply' );
 }
}
add_action( 'wp_enqueue_scripts', 'roofers_scripts' );



/**
 * Implement the Custom Header feature.
 */
require ROOFERS_THEMEINCLUDES . '/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require ROOFERS_THEMEINCLUDES . '/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require ROOFERS_THEMEINCLUDES . '/extras.php';
/**
 * bootstrap nav-walker .
 */
require ROOFERS_THEMEINCLUDES . '/wp_bootstrap_navwalker.php';

/**
 * Customizer additions.
 */
require ROOFERS_THEMEINCLUDES . '/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require ROOFERS_THEMEINCLUDES . '/jetpack.php';
/**
 * Load Widgets file.
 */
require ROOFERS_THEMEINCLUDES . '/widgets/thumb_listing_widget.php';
require ROOFERS_THEMEINCLUDES . '/widgets/services_list.php';
require ROOFERS_THEMEINCLUDES . '/widgets/work_lists.php';

// Redux Initialize
require_once (ROOFERS_THEMEINCLUDES . '/roofers-theme-config.php');

// Redux Initialize
require_once (ROOFERS_THEMEINCLUDES . '/required_plugins.php');

require_once (ROOFERS_THEMEINCLUDES . '/theme-design.php');
require_once (ROOFERS_THEMEINCLUDES . '/roofers-wbc-configs.php');


/*Custom functions*/

function roofers_post_excerpt_length( $length ) {
	return 20;
}
add_filter( 'excerpt_length', 'roofers_post_excerpt_length', 999 );

function roofers_post_excerpt_more( $more ) {
    return '';//you can change this to whatever you want
}
add_filter( 'excerpt_more', 'roofers_post_excerpt_more' );

add_filter( 'body_class', 'roofers_custom_class' );
function roofers_custom_class( $classes ) {
	global $post;
	if(!empty($post->ID)){
	$title_display = get_post_meta( $post->ID, 'roofers_hide_page_title', true );
    if ( is_home()  ) {
        $classes[] = 'home';
    }
    if ( $title_display == 'yes' ) {
        $classes[] = 'hide_page_title';
    }
	
    return $classes;
	}
}

/*
* set static page on demo import
*/

function roofers_static_page_set() {


	$homepage = get_page_by_title( 'Home' );
 
	if ( $homepage ) {
		update_option( 'page_on_front', $homepage->ID );
		update_option( 'show_on_front', 'page' );
	}
 
}


add_action( 'wbc_importer_after_content_import', 'roofers_static_page_set', 10, 2 );


 add_action( 'wbc_importer_after_content_import', 'roofers_set_main_menu', 10, 2 );

/*
* set header menu on demo import
*/

function roofers_set_main_menu() {

	$menu_header = get_term_by( 'name', 'Header Menu', 'nav_menu' );

    $menu_header_id = $menu_header->term_id;
	if ( $menu_header_id == 0 ) {
		$menu_header_id = wp_create_nav_menu( 'Header Menu' );
	}

	$locations = get_theme_mod( 'nav_menu_locations' );

    //set the menu to the new location and save into database
	$locations['primary'] = $menu_header_id;
	set_theme_mod( 'nav_menu_locations', $locations );

}
/*
* Current date shortcode
*/

function current_date_hook() {
    $current_date =  date('Y'); 
	return $current_date;
}
add_shortcode( 'current_date', 'current_date_hook');
