<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if (!class_exists('Redux')) {
    return;
}


// This is your option name where all the Redux data is stored.
$opt_name = "roofers_option";

// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters('redux_demo/opt_name', $opt_name);

/*
 *
 * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
 *
 */


/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => __('Theme Options', 'roofers'),
    'page_title' => __('Theme Options', 'roofers'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => true,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-layout',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    
    // OPTIONAL -> Give you extra features
    'page_priority' => 30,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => 'dashicons-portfolio',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.
    
    'show_options_object' => false,
    // Removes the options_object panel when not used.
    
    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.
    
    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.
    
    // HINTS
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'red',
            'shadow' => true,
            'rounded' => false,
            'style' => ''
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right'
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover'
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'duration' => '500',
                'event' => 'click mouseleave'
            )
        )
    )
);

// ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
$args['admin_bar_links'][] = array(
    'id' => 'redux-docs',
    'href' => esc_url('http://docs.reduxframework.com/','roofers'),
    'title' => __('Documentation', 'roofers')
);

$args['admin_bar_links'][] = array(
    //'id'    => 'redux-support',
    'href' => esc_url('https://github.com/ReduxFramework/redux-framework/issues','roofers'),
    'title' => __('Support', 'roofers')
);

$args['admin_bar_links'][] = array(
    'id' => 'redux-extensions',
    'href' => esc_url('reduxframework.com/extensions','roofers'),
    'title' => __('Extensions', 'roofers')
);

// SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
$args['share_icons'][] = array(
    'url' => esc_url('https://github.com/ReduxFramework/ReduxFramework','roofers'),
    'title' =>  __('Visit us on GitHub', 'roofers'),
    'icon' => 'el el-github'
    //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
);
$args['share_icons'][] = array(
    'url' => esc_url('https://www.facebook.com/pages/Redux-Framework/243141545850368','roofers'),
    'title' => __('Like us on Facebook', 'roofers'),
    'icon' => 'el el-facebook'
);
$args['share_icons'][] = array(
    'url' => esc_url('http://twitter.com/reduxframework','roofers'),
    'title' => __('Follow us on Twitter', 'roofers'),
    'icon' => 'el el-twitter'
);
$args['share_icons'][] = array(
    'url' => esc_url('http://www.linkedin.com/company/redux-framework','roofers'),
    'title' => __('Find us on LinkedIn', 'roofers'),
    'icon' => 'el el-linkedin'
);

// Panel Intro text -> before the form
if (!isset($args['global_variable']) || $args['global_variable'] !== false) {
    if (!empty($args['global_variable'])) {
        $v = $args['global_variable'];
    } else {
        $v = str_replace('-', '_', $args['opt_name']);
    }
    $args['intro_text'] = sprintf(__('<p> Customize your website using the roofers theme options panel. </p>', 'roofers'), $v);
} else {
    $args['intro_text'] = __('<p> Customize your website using the roofers theme options panel. </p>', 'roofers');
}

// Add content after the form.
$args['footer_text'] = __('<p> If you like our theme and support, please rate us 5 stars on themeforest. </p>', 'roofers');

Redux::setArgs($opt_name, $args);

/*
 * ---> END ARGUMENTS
 */
    /*
     * ---> END ARGUMENTS
     */


    /* EXT LOADER */
    if(!function_exists('redux_register_custom_extension_loader')) :
    function redux_register_custom_extension_loader($ReduxFramework) {
        $path = dirname( __FILE__ ) . '/extensions/';
        $folders = scandir( $path, 1 );        
        foreach($folders as $folder) {
            if ($folder === '.' or $folder === '..' or !is_dir($path . $folder) ) {
                continue;   
            } 
            $extension_class = 'ReduxFramework_Extension_' . $folder;
            if( !class_exists( $extension_class ) ) {
                // In case you wanted override your override, hah.
                $class_file = $path . $folder . '/extension_' . $folder . '.php';
                $class_file = apply_filters( 'redux/extension/'.$ReduxFramework->args['opt_name'].'/'.$folder, $class_file );
                if( $class_file ) {
                    require_once( $class_file );
                    $extension = new $extension_class( $ReduxFramework );
                }
            }
        }
    }
    // Modify {$redux_opt_name} to match your opt_name
    add_action("redux/extensions/".$opt_name ."/before", 'redux_register_custom_extension_loader', 0);
    endif;


/*
 * ---> START HELP TABS
 */

$tabs = array(
    array(
        'id' => 'redux-help-tab-1',
        'title' => __('Theme Information 1', 'roofers'),
        'content' => __('<p>This is the tab content, HTML is allowed.</p>', 'roofers')
    ),
    array(
        'id' => 'redux-help-tab-2',
        'title' => __('Theme Information 2', 'roofers'),
        'content' => __('<p>This is the tab content, HTML is allowed.</p>', 'roofers')
    )
);
Redux::setHelpTab($opt_name, $tabs);

// Set the help sidebar
$content = __('<p>This is the sidebar content, HTML is allowed.</p>', 'roofers');
Redux::setHelpSidebar($opt_name, $content);


/*
 * <--- END HELP TABS
 */


/*
 *
 * ---> START SECTIONS
 *
 */

/*
As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for
*/

// -> START Panel OPtions

/*
 *
 * --> General Sections Tab
 *
 */

// -> Section Title
Redux::setSection($opt_name, array(
    'id' => 'general_tab',
    'title' => esc_html__('General', 'roofers'),
    'desc' => esc_html__('All the general settings options are listed here', 'roofers'),
    'icon' => 'el el-home',
    'fields' => array(
        // -> Image Logo
        array(
            'id' => 'roofers_theme_logo',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Logo', 'roofers'),
            'compiler' => 'true',
            //'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
            'subtitle' => esc_html__('Upload your logo', 'roofers'),
            'default' => array(
                'url' => ''
            )
        ),
          // -> Logo Height
        array(
            'id' => 'logo_height',
            'type' => 'slider',
            'url' => true,
            'title' => esc_html__('Logo Height', 'roofers'),
            'compiler' => 'true',
            //'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
            'subtitle' => esc_html__('Set the height of the logo', 'roofers'),
            "default"   => 65,
             "min"       => 1,
            "step"      => 1,
            "max"       => 500,
            'display_value' => 'label'
        ),
        
        // -> Preloader enable or disable option
        array(
            'id' => 'preloader_display',
            'type' => 'switch',
            'title' => esc_html__('Preloader', 'roofers'), 
            'subtitle' => esc_html__( 'Enable or Disable Preloader', 'roofers' ),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
            ),
        // -> Breadcrumb enable or disable option
        array(
            'id' => 'breadcrumb_display',
            'type' => 'switch',
            'title' => esc_html__('Breadcrumb', 'roofers'), 
            'subtitle' => esc_html__( 'Enable or Disable Breadcrumb', 'roofers' ),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
            ),
        // -> Theme Button style
        array(
            'id' => 'btn_style',
            'type' => 'select',
            'title' => esc_html__('Button style', 'roofers'), 
            'subtitle' => esc_html__( 'Select the Button style', 'roofers' ),
            'options'  => array(
            '1' => 'Skew',
            '2' => 'Flat',
        
            ),
            'default' => '1',

            ),
        
        //Topbar Compnay name

        array(
            'id' => 'topbar_company_name',
            'type' => 'text',
            'title' => esc_html__('Topbar Location', 'roofers'), 
            'subtitle' => esc_html__( 'Enter the Company Name to be displayed at Infocard', 'roofers' ),
            'default' => 'Roofers Roofing Company',
            'validate' => 'text',
            'placeholder' => esc_html__('Enter here company name','roofers')
            ),

        array(
            'id' => 'topbar_address',
            'type' => 'text',
            'title' => esc_html__('Topbar Location', 'roofers'), 
            'subtitle' => esc_html__( 'Enter the Location to be displayed at Topbar', 'roofers' ),
            'required' => array(
                'topbar_display', "=", 1
            ),
            'default' => 'Brooklyn, NY 10036, United States',
            'validate' => 'text',
            'placeholder' => esc_html__('Enter your Location here','roofers')
            ),

        array(
            'id' => 'topbar_phone_no',
            'type' => 'text',
            'title' => esc_html__('Topbar Phone No.', 'roofers'), 
            'subtitle' => esc_html__( 'Enter the address to be displayed at Topbar', 'roofers' ),
            'required' => array(
                'topbar_display', "=", 1
            ),
            'default' => '1-800-123-1234',
            'placeholder' => esc_html__('Enter your phone no. here','roofers')
            ),

        array(
            'id' => 'topbar_email',
            'type' => 'text',
            'title' => esc_html__('Topbar Email', 'roofers'), 
            'subtitle' => esc_html__( 'Enter the phone no. to be displayed at Topbar', 'roofers' ),
            'required' => array(
                'topbar_display', "=", 1
            ),
            'validate' => 'email',
            'default' => 'info@roofers.com',
            'placeholder' => esc_html__('Enter your email here','roofers')
            ),

     

        array(
            'id' => 'google_map_address_link',
            'type' => 'text',
            'title' => esc_html__('Google Map Address Link', 'roofers'), 
            'subtitle' => esc_html__( 'Enter the Google Map Address Link to be displayed at Infocard', 'roofers' ),
            'default' => esc_url('https://www.google.com/maps/place/Brooklyn,+NY/@40.6451594,-74.0850816,11z/data=!3m1!4b1!4m5!3m4!1s0x89c24416947c2109:0x82765c7404007886!8m2!3d40.6781784!4d-73.9441579','roofers'),
            'validate' => 'text',
            'placeholder' => esc_html__('Enter your google map address link here','roofers')
            ),

    

        // -> Back to top switch        
        array(
            'id' => 'back_top_enable',
            'type' => 'switch',
            'title' => esc_html__('Enable Back to top Icon?', 'roofers'),
            'subtitle' => esc_html__('Select the back to top icon to be hidden or displayed', 'roofers'),
            'default' => true,
            'on' =>'Enabled',
            'off' =>'Disabled',            
        ),  
        // -> 404 page background image
        array(
            'id' => 'bg_404',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Background Image for 404 Page', 'roofers'),
            'compiler' => 'true',
            //'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
            'subtitle' => esc_html__('Upload your backgroud image for 404 page', 'roofers'),
            'default' => array(
                'url' => ''
            )
        ),
        // -> 404 page background image
        array(
            'id' => 'google_pin',
            'type' => 'media',
            'url' => true,
            'title' => esc_html__('Google Map Pin', 'roofers'),
            'compiler' => 'true',
            //'mode'      => false, // Can be set to false to allow any media type, or can also be set to any mime type.
            'subtitle' => esc_html__('Upload your google map pin', 'roofers'),
            'default' => array(
                'url' => ''
            )
        ),
        // -> Single Page Pagination
        array(
            'id' => 'sp_pagination',
            'type' => 'switch',
            'title' => esc_html__('Detail Page Pagination', 'roofers'), 
            'subtitle' => esc_html__( 'Enable or Disable detail page pagination', 'roofers' ),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
            ),
        // -> Single Page Category
        array(
            'id' => 'sp_cat',
            'type' => 'switch',
            'title' => esc_html__('Detail Page Category', 'roofers'), 
            'subtitle' => esc_html__( 'Enable or Disable detail page category ', 'roofers' ),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
            ),
        // -> Single Page Tags
        array(
            'id' => 'sp_tag',
            'type' => 'switch',
            'title' => esc_html__('Detail Page Tags', 'roofers'), 
            'subtitle' => esc_html__( 'Enable or Disable detail page tags ', 'roofers' ),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
            ),
         // -> Custom Post type name change for Services
        array(
            'id' => 'cp_sr',
            'type' => 'text',
            'title' => esc_html__('Change Custom Post Type Name for Services', 'roofers'), 
            'subtitle' => esc_html__( 'Enter the name of the post type name for services. After change the name refresh Permalinks', 'roofers' ),
            'default' => 'services',
            'validate' => 'text',
            'placeholder' => esc_html__('Enter your custom post type name for services','roofers')
            ),
        // -> Custom Post type name change for Works
        array(
            'id' => 'cp_wk',
            'type' => 'text',
            'title' => esc_html__('Change Custom Post Type Name for Works', 'roofers'), 
            'subtitle' => esc_html__( 'Enter the name of the post type name for work. After change the name refresh Permalinks', 'roofers' ),
            'default' => 'works',
            'validate' => 'text',
            'placeholder' => esc_html__('Enter your custom post type name for work','roofers')
            ),
              // -> Custom Post type naame change for Team
        array(
            'id' => 'cp_tm',
            'type' => 'text',
            'title' => esc_html__('Change Custom Post Type Name for Team', 'roofers'), 
            'subtitle' => esc_html__( 'Enter the name of the post type name for team. After change the name refresh Permalinks', 'roofers' ),
            'default' => 'team',
            'validate' => 'text',
            'placeholder' => esc_html__('Enter your custom post type name for team','roofers')
            ),
              
    )
));

/*
 *
 * --> Header Sections Tab
 *
 */

// -> Section Title
Redux::setSection($opt_name, array(
    'id' => 'header_tab',
    'title' => esc_html__('Header', 'roofers'),
    'desc' => esc_html__('All the header related options are listed here', 'roofers'),
    'icon' => 'el el-screen',
    'fields' => array(
    
        // -> Header style
        array(
            'id'       => 'header_select',
            'type'     => 'image_select',
            'title'    => esc_html__('Header style', 'roofers'), 
            'subtitle' => esc_html__('Select Header style', 'roofers'),
            // Must provide key => value pairs for select options
            'options'  => array(
            // Array of preset options
            '1'      => array(
            'alt'   => 'header 1', 
            'img'   => ROOFERS_THEMEROOT.'/images/header-1.png', 
            ),  
            '2'      => array(
            'alt'   => 'header 2', 
            'img'   => ROOFERS_THEMEROOT.'/images/header-2.png', 
            ),
            '3'      => array(
            'alt'   => 'header 3', 
            'img'   => ROOFERS_THEMEROOT.'/images/header-3.png', 
            ),
            ),
            'default'  => '1',
            ),
            // -> Menu animation
        array(
            'id' => 'menu_animation',
            'type' => 'select',
            'title' => esc_html__('Menu Animation style', 'roofers'), 
            'subtitle' => esc_html__( 'Select the animation for menu Dropdown', 'roofers' ),
            'options'  => array(
            'zoomIn' => 'zoomIn',
            'fadeInUp' => 'fadeInUp',
            'fadeIn' => 'fadeIn',
            'slideInUp' => 'slideInUp ',
                ),
            'default'  => 'zoomIn',
            ),
            
    // -> Topbar enable or disable option
        array(
            'id' => 'topbar_display',
            'type' => 'switch',
            'title' => esc_html__('Topbar', 'roofers'), 
            'subtitle' => esc_html__( 'Enable or Disable Topbar', 'roofers' ),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
            ),
        // -> Info Card Hover
        array(
            'id' => 'logo_infocard',
            'type' => 'switch',
            'title' => esc_html__('Logo Hover Me', 'roofers'),
            'subtitle' => esc_html__('Manage your Logo Hover Me settings', 'roofers'),
            'default' => true
        ), 
    // -> Search bar enable or disable option
        array(
            'id' => 'search_display',
            'type' => 'switch',
            'title' => esc_html__('Search Bar', 'roofers'), 
            'subtitle' => esc_html__( 'Enable or Disable Search Bar', 'roofers' ),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
            ),
        
        // -> Topbar Social Icons Switch
        array(
            'id' => 'top_social_icons',
            'type' => 'switch',
            'title' => esc_html__('Top Bar Social Icons Enable/Disable', 'roofers'),
            'subtitle' => esc_html__('Manage your top bar social icons settings', 'roofers'),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
        ),
        // -> Infocard Social Icons Switch
        array(
            'id' => 'infocard_social_icons',
            'type' => 'switch',
            'title' => esc_html__('Info Card Social Icons Enable/Disable', 'roofers'),
            'subtitle' => esc_html__('Manage your Info Card social icons settings', 'roofers'),
            'default' => '1',
            'on' =>'Enabled',
            'off' =>'Disabled',
        ),
        
        // -> Facbook Link
        array(
            'id' => 'top_icons_facebook',
            'type' => 'text',
            'title' => esc_html__('Facebook', 'roofers'),
            'subtitle' => esc_html__('Enter your facebook URL', 'roofers'),
            'default' => 'https://www.facebook.com',
            'validate' => 'url',
            'placeholder' => __('Enter your Facebook url here','roofers')
        ),
        
        // -> Twitter Link
        array(
            'id' => 'top_icons_twitter',
            'type' => 'text',
            'title' => esc_html__('Twitter', 'roofers'),
            'subtitle' => esc_html__('Enter your twitter URL', 'roofers'),
            'default' => 'https://twitter.com',
            'validate' => 'url',
            'placeholder' => __('Enter your Twitter url here','roofers')
        ),
        
        // -> Instagram Link
        array(
            'id' => 'top_icons_instagram',
            'type' => 'text',
            'title' => esc_html__('Instagram', 'roofers'),
            'subtitle' => esc_html__('Enter your instagram URL', 'roofers'),
            'default' => 'https://www.instagram.com/',
            'validate' => 'url',
            'placeholder' => __('Enter your Instagram url here','roofers')
        ),
        
        // -> Linkedin Link
        array(
            'id' => 'top_icons_linkedin',
            'type' => 'text',
            'title' => esc_html__('Linkedin', 'roofers'),
            'subtitle' => esc_html__('Enter your Linkedin URL', 'roofers'),
            'default' => 'https://in.linkedin.com/',
            'validate' => 'url',
            'placeholder' =>  __('Enter your Linkedin url here','roofers')
        ),
        
        // -> Youtube Link
        array(
            'id' => 'top_icons_youtube',
            'type' => 'text',
            'title' => esc_html__('YouTube', 'roofers'),
            'subtitle' => esc_html__('Enter your YouTube URL', 'roofers'),
            'default' => 'https://www.youtube.com/',
            'validate' => 'url',
            'placeholder' => __('Enter your YouTube url here','roofers')
        ),
        
        // -> Google+ Link
        array(
            'id' => 'top_icons_googleplus',
            'type' => 'text',
            'title' => esc_html__('Google Plus', 'roofers'),
            'subtitle' => esc_html__('Enter your Google Plus URL', 'roofers'),
            'default' => 'https://plus.google.com/',
            'validate' => 'url',
            'placeholder' => __('Enter your googleplus url here','roofers')
        ),
        
        // -> Google+ Link
        array(
            'id' => 'top_icons_dribble',
            'type' => 'text',
            'title' => esc_html__('Dribble', 'roofers'),
            'subtitle' => esc_html__('Enter your Dribble URL', 'roofers'),
            'default' => 'https://dribble.com/',
            'validate' => 'url',
            'placeholder' => __('Enter your dribble url here','roofers')
        ),  
    )
));

/*
 *
 * --> Sidebar Sections Tab
 *
 */

// -> Section Title
Redux::setSection($opt_name, array(
    'id' => 'sidebar_tab',
    'title' => esc_html__('Sidebar', 'roofers'),
    'desc' => esc_html__('All the Sidebar settings options are listed here', 'roofers'),
    'icon' => 'el el-list',
    'fields' => array(
        // -> Blog Sidebar Option
        array(
            'id'       => 'blog_sidebar',
            'type'     => 'image_select',
            'title'    => __( 'Blog Global Sidebar', 'roofers' ),
            'subtitle' => __( 'Select your Blog page global sidebar here', 'roofers' ),
            'desc'     => __( 'This selection will be applied to Blog, Blog Single and Blog Archive Page.', 'roofers' ),
            //Must provide key => value pairs for radio options
            'options' => array(
                '1'  => array(
                    'alt' => 'No Sidebar',
                    'img' => ReduxFramework::$_url . 'assets/img/1col.png'
                ),
                '2'  => array(
                    'alt' => 'Left Sidebar',
                    'img' => ReduxFramework::$_url . 'assets/img/2cl.png'
                ),
                '3' => array(
                    'alt' => 'Right Side',
                    'img' => ReduxFramework::$_url . 'assets/img/2cr.png'
                ),
            ),
            'default'  => '3'
            ),

    )
));


/*
 *
 * --> Colors Sections Tab
 *
 */

// -> Section Title
Redux::setSection( $opt_name, array(
    'id' => 'colors',
    'title' => esc_html__('Colors', 'roofers'),
    'desc' => esc_html__('All the Color options of the theme are listed here', 'roofers'),
    'customizer_width' => '400px',
    'icon' => 'el el-brush',    
) );

Redux::setSection($opt_name, array(
    'id' => 'global_colors',
    'title' => esc_html__('Global', 'roofers'),
    'desc' => esc_html__('All the Global Color options of the theme are listed here', 'roofers'),
    'icon' => 'el el-globe',
    'subsection'       => true,
    'customizer_width' => '450px',
    'fields' => array(
        //Accent main theme color
        array(
            'id' => 'accent_color',
            'type' => 'link_color',
            'title' => esc_html__('Accent Colors', 'roofers'),
            'subtitle' => esc_html__('Insert your default accent color for the whole website', 'roofers'),
            'default' => array(
                'regular' => '#da1c22',
                'hover' => '#fff',
            ),
            'validate' => 'color',
            
        ),
        // -> Header Topbar background
        array(
            'id' => 'topbar_bg_color',
            'type' => 'color_rgba',
            'title' => esc_html__('Top bar background color', 'roofers'),
            'subtitle' => esc_html__('Insert your top bar background color', 'roofers'),
            'validate' => 'colorrgba',
            'default' => array(
                'color' => '',
                'alpha' => '1'
            ),
            'output' => array(
                'background-color' => 'header.top-bar'
            )
        ),
        // -> Header Topbar Text Color      
        array(
            'id' => 'topbar_txt',
            'type' => 'color',
            'title' => esc_html__('Topbar Text Colors', 'roofers'),
            'subtitle' => esc_html__('Insert your colors for the text at the topbar', 'roofers'),
            'default' => '#000000',
            'validate' => 'color',
            'output' => array( 'color' => 'header.top-bar,.top-bar .for-contact-info a,header .info-address span.address-bk, header .info-address .fa, .info-mail .fa, .info-phone .fa' )
        ),
        // -> Header Topbar Social Icon background
        array(
            'id' => 'topbar_social_icons_bg',
            'type' => 'color',
            'title' => esc_html__('Topbar Social Icon Background Color', 'roofers'),
            'subtitle' => esc_html__('Insert your colors for the topbar social icon background color', 'roofers'),
            'default' => '#8a8585',
            'validate' => 'color',
            'output' => array( 'background-color' => 'header .top-bar-social-icon .social-icons li a' )
        ),
        // -> Header Topbar Social Icon Color
        array(
            'id' => 'topbar_social_icons_clr',
            'type' => 'color',
            'title' => esc_html__('Topbar Social Icon Color', 'roofers'),
            'subtitle' => esc_html__('Insert your colors for the topbar social icon color', 'roofers'),
            'default' => '#ffffff',
            'validate' => 'color',
            'output' => array( 'color' => 'header .top-bar-social-icon .social-icons li a' )
        ),  
        // -> Header Navigation background color
        array(
            'id' => 'nav_bg_color',
            'type' => 'color_rgba',
            'title' => esc_html__('Navigation background color', 'roofers'),
            'subtitle' => esc_html__('Insert your navigation background color', 'roofers'),
            'validate' => 'colorrgba',
            'default' => array(
                'color' => '',
                'alpha' => '1'
            ),
            'output' => array(
                'background-color' => '.navigation'
            )
        ),
        // -> Mobile Header Navigation background color
        array(
            'id' => 'mb_nav_bg_color',
            'type' => 'color_rgba',
            'title' => esc_html__('Mobile Navigation background color', 'roofers'),
            'subtitle' => esc_html__('Insert your navigation background color', 'roofers'),
            'validate' => 'colorrgba',
            'default' => array(
                'color' => '#fff',
                'alpha' => '1'
            ),
            
        ),
        // -> Header Navigation background color in mobile
        array(
            'id' => 'dp_nav_bg_color',
            'type' => 'color_rgba',
            'title' => esc_html__('Menu Navbar dropdown background color for  Mobile View', 'roofers'),
            'subtitle' => esc_html__('Insert your menu navbar background color for mobile view', 'roofers'),
            'validate' => 'colorrgba',
            'default' => array(
                'color' => '',
                'alpha' => '1'
            ),
            
        
        ),
        // -> Header Navigation Text Color
        array(
            'id' => 'nav_text_clr',
            'type' => 'color',
            'title' => esc_html__('Navigation Text Color', 'roofers'),
            'subtitle' => esc_html__('Insert your colors for navigation text color', 'roofers'),
            'default' => '#ffffff',
            'validate' => 'color',
           'output' => array( 'color' => '.navbar-nav > li > a' )
        ),
        // -> Header Navigation Dropdown Text Color
        array(
            'id' => 'dp_nav_text_clr',
            'type' => 'color',
            'title' => esc_html__('Navigation Dropdown Text Color', 'roofers'),
            'subtitle' => esc_html__('Insert your colors for navigation dropdown text color', 'roofers'),
            'default' => '#ffffff',
            'validate' => 'color',
         
        ),
        // -> Header Search icon Color
        array(
            'id' => 'sr_icon_clr',
            'type' => 'color',
            'title' => esc_html__('Search Icon Color', 'roofers'),
            'subtitle' => esc_html__('Insert your colors for search icon color', 'roofers'),
            'default' => '#ffffff',
            'validate' => 'color',
          
        ),
        
        // -> Preloader background color
        array(
            'id' => 'preloader_bg_color',
            'type' => 'color',
            'title' => esc_html__('Preloader Background Color', 'roofers'),
            'subtitle' => esc_html__('Insert your preloader background color', 'roofers'),
            'validate' => 'color',
            'default' => '#433b3b',
            'output' => array(
                'background-color' => '#loader'
            )
        ),

        // -> Back to top background
        array(
            'id' => 'back_top_bg',
            'type' => 'color',
            'title' => esc_html__('Back to Top background color', 'roofers'),
            'subtitle' => esc_html__('Insert your back to top background color', 'roofers'),
            'required' => array(
                'back_top_enable', "=", 1
            ),
            'default' => '#da1c22',
            'compiler' => 'true',
          
        ),  
        
        // -> Back to top icon
        array(
            'id' => 'back_top_icon',
            'type' => 'color',
            'title' => esc_html__('Back to Top icon color', 'roofers'),
            'subtitle' => esc_html__('Insert your back to top icon color', 'roofers'),
            'default' =>'#ffffff', 
            'validate' => 'color',
            'required' => array(
                'back_top_enable', "=", 1
            ),
        ),
        array(
            'id' => 'logo_bg_color',
            'type' => 'color',
            'title' => esc_html__('Logo backgorund color', 'roofers'),
            'default' =>'#da1c22', 
            'validate' => 'color'
        ),
        // -> Footer Background Color
        array(
            'id' => 'footer_bg',
            'type' => 'color',
            'title' => esc_html__('Footer Background Color', 'roofers'),
            'subtitle' => esc_html__('Insert your background color for footer', 'roofers'),
            'default' =>'#19171c', 
            'validate' => 'color',
        ),
        // -> Footer Text Color
        array(
            'id' => 'footer_txt',
            'type' => 'color',
            'title' => esc_html__('Footer Text Color', 'roofers'),
            'subtitle' => esc_html__('Insert your text color for footer', 'roofers'),
            'default' =>'#8b8b8b', 
            'validate' => 'color',
        ),
        // -> Footer Widget Title Color
        array(
            'id' => 'ftr_wd_clr',
            'type' => 'color',
            'title' => esc_html__('Footer Widget Title Color', 'roofers'),
            'subtitle' => esc_html__('Insert your widget title color for footer', 'roofers'),
            'default' =>'#fff', 
            'validate' => 'color',
        ),
        // -> Footer Link Color
        array(
            'id' => 'footer_lk_clr',
            'type' => 'color',
            'title' => esc_html__('Footer Link Color', 'roofers'),
            'subtitle' => esc_html__('Insert your link color for footer', 'roofers'),
            'default' =>'#a8a8a8', 
            'validate' => 'color',

        ),
        // -> Footer Link Color
        array(
            'id' => 'footer_lk_hr_clr',
            'type' => 'color',
            'title' => esc_html__('Footer Link Hover Color', 'roofers'),
            'subtitle' => esc_html__('Insert your link hover color for footer', 'roofers'),
            'default' =>'#fff', 
            'validate' => 'color',
        ),
        // -> Footer Border Color
        array(
            'id' => 'footer_brd_clr',
            'type' => 'color',
            'title' => esc_html__('Footer Border Color', 'roofers'),
            'subtitle' => esc_html__('Insert your border color for footer', 'roofers'),
            'default' =>'#db1c23', 
            'validate' => 'color',
        ),
        // -> Footer Icon Color
        array(
            'id' => 'footer_icon_clr',
            'type' => 'color',
            'title' => esc_html__('Footer Icon Color', 'roofers'),
            'subtitle' => esc_html__('Insert your icon color for footer', 'roofers'),
            'default' =>'#db1c23', 
            'validate' => 'color',
        ),
        // -> Footer copyright background Color
        array(
            'id' => 'ftr_cp_bg_clr',
            'type' => 'color',
            'title' => esc_html__('Footer Copyright Background Color', 'roofers'),
            'subtitle' => esc_html__('Insert your Copyright Background color for footer', 'roofers'),
            'default' =>'#19171c', 
            'validate' => 'color',
        ),
        
    )
) );

Redux::setSection( $opt_name, array(
        'id'         => 'typography_tab',
        'title'      => esc_html__( 'Typography', 'roofers' ),
        'desc'       => esc_html__( 'All the advanced options are listed here ', 'roofers' ),
        'icon'   => 'el el-font',
        'fields'     => array(
            array(
                            'id'       => 'body_font',
                            'type'     => 'typography',
                            'title'    => esc_html__( 'Body Font', 'roofers' ),
                            'subtitle' => esc_html__( 'Specify the body font properties.', 'roofers' ),
                            'color'    => false,
                            'compiler' => 'true',
                            'output'    => array('body.roofers_body'),
                            'google'   => true,
                            'subsets'  => false,
                            'letter-spacing' =>true,
                            'preview' =>true,
                            'default'  => array(
                                'font-family' => 'Roboto',
                                'font-weight' => '',
                                'text-align' => '',
                                'font-size' => '',
                                'line-height' => '',
                                'letter-spacing' => '0',
                            ),
                        ),
                        array(
                            'id'       => 'menu_font',
                            'type'     => 'typography',
                            'title'    => esc_html__( 'Menu Font', 'roofers' ),
                            'subtitle' => esc_html__( 'Specify the menu font properties.', 'roofers' ),
                            'color'    =>false,
                            'google'   => true,
                            'letter-spacing' =>true,
                            'subsets'  => false,
                            'preview' =>true,
                            'default'  => array(
                                'font-family' => 'Roboto',
                                'font-weight' => '',
                                'font-style' => '',
                                'text-align' => '',
                                'font-size' => '',
                                'line-height' => '',
                                'letter-spacing' => '0',
                            ),
                        ),
                        array(
                            'id'       => 'h1_font',
                            'type'     => 'typography',
                            'title'    => esc_html__( 'Heading Font H1', 'roofers' ),
                            'subtitle' => esc_html__( 'Specify the heading font properties for H1.', 'roofers' ),
                            'color'    =>true,
                            'google'   => true,
                            'letter-spacing' =>true,
                            'subsets'  => false,
                            'preview' =>true,
                            'default'  => array(
                                'font-family' => 'Roboto',
                                'font-weight' => '',
                                'font-style' => 'normal',
                                'text-align' => '',
                                'font-size' => '',
                                'line-height' => '',
                                'letter-spacing' => '0',
                                'color'  => '',
                                'important' => true,
                                
                            ),
                        ),
                        array(
                            'id'       => 'h2_font',
                            'type'     => 'typography',
                            'title'    => esc_html__( 'Heading Font H2', 'roofers' ),
                            'subtitle' => esc_html__( 'Specify the heading font properties for H2.', 'roofers' ),
                            'color'    =>true,
                            'google'   => true,
                            'letter-spacing' =>true,
                            'subsets'  => false,
                            'preview' =>true,
                            'default'  => array(
                                'font-family' => 'Roboto',
                                'font-weight' => '',
                                'font-style' => 'normal',
                                'text-align' => '',
                                'font-size' => '',
                                'line-height' => '',
                                'letter-spacing' => '0',
                                'color'  => '',
                                'important' => true,
                                
                            ),
                        ),
                        array(
                            'id'       => 'h3_font',
                            'type'     => 'typography',
                            'title'    => esc_html__( 'Heading Font H3', 'roofers' ),
                            'subtitle' => esc_html__( 'Specify the heading font properties for H3.', 'roofers' ),
                            'color'    =>true,
                            'google'   => true,
                            'letter-spacing' =>true,
                            'subsets'  => false,
                            'preview' =>true,
                            'default'  => array(
                                'font-family' => 'Roboto',
                                'font-weight' => '',
                                'font-style' => 'normal',
                                'text-align' => '',
                                'font-size' => '',
                                'line-height' => '',
                                'letter-spacing' => '0',
                                'color'  => '',
                                'important' => true,
                                
                            ),
                        ),
                        array(
                            'id'       => 'h4_font',
                            'type'     => 'typography',
                            'title'    => esc_html__( 'Heading Font H4', 'roofers' ),
                            'subtitle' => esc_html__( 'Specify the heading font properties for H4.', 'roofers' ),
                            'color'    =>true,
                            'google'   => true,
                            'letter-spacing' =>true,
                            'subsets'  => false,
                            'preview' =>true,
                            'default'  => array(
                                'font-family' => 'Roboto',
                                'font-weight' => '',
                                'font-style' => 'normal',
                                'text-align' => '',
                                'font-size' => '',
                                'line-height' => '',
                                'letter-spacing' => '0',
                                'color'  => '',
                                'important' => true,
                                
                            ),
                        ),
                        array(
                            'id'       => 'h5_font',
                            'type'     => 'typography',
                            'title'    => esc_html__( 'Heading Font H5', 'roofers' ),
                            'subtitle' => esc_html__( 'Specify the heading font properties for H5.', 'roofers' ),
                            'color'    =>true,
                            'google'   => true,
                            'letter-spacing' =>true,
                            'subsets'  => false,
                            'preview' =>true,
                            'default'  => array(
                                'font-family' => 'Roboto',
                                'font-weight' => '',
                                'font-style' => 'normal',
                                'text-align' => '',
                                'font-size' => '',
                                'line-height' => '',
                                'letter-spacing' => '0',
                                'color'  => '',
                                'important' => true,
                                
                            ),
                        ),
                        array(
                            'id'       => 'h6_font',
                            'type'     => 'typography',
                            'title'    => esc_html__( 'Heading Font H6', 'roofers' ),
                            'subtitle' => esc_html__( 'Specify the heading font properties for H6.', 'roofers' ),
                            'color'    =>true,
                            'google'   => true,
                            'letter-spacing' =>true,
                            'subsets'  => false,
                            'preview' =>true,
                            'default'  => array(
                                'font-family' => 'Roboto',
                                'font-weight' => '',
                                'font-style' => 'normal',
                                'text-align' => '',
                                'font-size' => '',
                                'line-height' => '',
                                'letter-spacing' => '0',
                                'color'  => '',
                                'important' => true,
                                
                            ),
                        ),
                        
        )
    ) );

Redux::setSection( $opt_name, array(
        'id'         => 'footer_tab',
        'title'      => esc_html__( 'Footer', 'roofers' ),
        'desc'       => esc_html__( 'All the footer related options are listed here ', 'roofers' ),
        'icon'   => 'el el-bookmark el el-small',
        'fields'     => array(
                        array(
                            'id' => 'footer_widget_enable',
                            'type' => 'switch',
                            'title' => esc_html__('Footer Widget Area', 'roofers'), 
                            'subtitle' => esc_html__( 'Enable or Disable footer widget area globally', 'roofers' ),
                            'default' => '1',
                            'on' =>'Enabled',
                            'off' =>'Disabled',
                            ),
                        array(
                            'id'       => 'footer_columns',
                            'type'     => 'button_set',
                            'title'    => __( 'Select No. of columns for the footer', 'roofers' ),
                            'subtitle' => __( 'No validation can be done on this field type', 'roofers' ),
                            'desc'     => __( 'This is the description field, again good for additional info.', 'roofers' ),
                            'required' => array( 'footer_widget_enable', "=", 1 ),
                            //Must provide key => value pairs for radio options
                            'options'  => array(
                                '1' => '1 Column',
                                '2' => '2 Column',
                                '3' => '3 Column'
                            ),
                            'default'  => '3'
                            ),                        
                        array(
                            'id' => 'copyright_txtbox',
                            'type' => 'editor',
                            'title' => esc_html__('Copyright Text', 'roofers'), 
                            'subtitle' =>esc_html__('Enter your footer copyright text here', 'roofers'),
                            'desc'     => __( 'Use [current_date] shortcode for getting Current date.', 'roofers' ),
                            'default' => '&copy; Copyright'.  date('Y') .' All Rights Reserved by <a href="#"> roofers </a>',
                        ),
                        array(
                            'id'       => 'copyright_position',
                            'type'     => 'button_set',
                            'title'    => __( 'Select the position for the copyright text', 'roofers' ),
                            'subtitle' => __( 'No validation can be done on this field type', 'roofers' ),
                            'desc'     => __( 'This is the description field, again good for additional info.', 'roofers' ),
                            //Must provide key => value pairs for radio options
                            'options'  => array(
                                '1' => 'Left',
                                '2' => 'Center',
                                '3' => 'Right'
                            ),
                            'default'  => '1'
                            ), 

        )
    ) );
        Redux::setSection( $opt_name, array(
        'icon'   => 'el el-cog-alt',
        'title'  => __( 'Custom Code', 'roofers' ),
        'fields' => array(
            
            array (
                'title' => __('Custom CSS', 'roofers'),
                'subtitle' => __('Paste your custom CSS code here.', 'roofers'),
                'id' => 'custom_css',
                'type' => 'ace_editor',
                'mode' => 'css',
            ),
            
            array (
                'title' => __('Header JavaScript Code', 'roofers'),
                'subtitle' => __('Paste your custom JS code here. The code will be added to the header of your site.', 'roofers'),
                'id' => 'header_js',
                'type' => 'ace_editor',
                'mode' => 'javascript',
            ),
            
            array (
                'title' => __('Footer JavaScript Code', 'roofers'),
                'subtitle' => __('Here is the place to paste your Google Analytics code or any other JS code you might want to add to be loaded in the footer of your website.', 'roofers'),
                'id' => 'footer_js',
                'type' => 'ace_editor',
                'mode' => 'javascript',
            ),
            
        )
        
    ) );

/*
 * <--- END SECTIONS
 */


/*
 *
 * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
 *
 */

/*
 *
 * --> Action hook examples
 *
 */

// If Redux is running as a plugin, this will remove the demo notice and links
//add_action( 'redux/loaded', 'remove_demo' );

// Function to test the compiler hook and demo CSS output.
// Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
//add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

// Change the arguments after they've been declared, but before the panel is created
//add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

// Change the default value of a field after it's been set, but before it's been useds
//add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

// Dynamically add a section. Can be also used to modify sections/fields
//add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

/**
 * This is a test function that will let you see when the compiler hook occurs.
 * It only runs if a field    set with compiler=>true is changed.
 * */
if (!function_exists('compiler_action')) {
    function compiler_action($options, $css, $changed_values)
    {
        echo '<h1>The compiler hook has run!</h1>';
        echo "<pre>";
        print_r($changed_values); // Values that have changed since the last save
        echo "</pre>";
    }
}

/**
 * Custom function for the callback validation referenced above
 * */
if (!function_exists('redux_validate_callback_function')) {
    function redux_validate_callback_function($field, $value, $existing_value)
    {
        $error   = false;
        $warning = false;
        
        //do your validation
        if ($value == 1) {
            $error = true;
            $value = $existing_value;
        } elseif ($value == 2) {
            $warning = true;
            $value   = $existing_value;
        }
        
        $return['value'] = $value;
        
        if ($error == true) {
            $return['error'] = $field;
            $field['msg']    = 'your custom error message';
        }
        
        if ($warning == true) {
            $return['warning'] = $field;
            $field['msg']      = 'your custom warning message';
        }
        
        return $return;
    }
}

/**
 * Custom function for the callback referenced above
 */
if (!function_exists('redux_my_custom_field')) {
    function redux_my_custom_field($field, $value)
    {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
}

/**
 * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
 * so you must use get_template_directory_uri() if you want to use any of the built in icons
 * */
if (!function_exists('dynamic_section')) {
    function dynamic_section($sections)
    {
        //$sections = array();
        $sections[] = array(
            'title' => __('Section via hook', 'roofers'),
            'desc' => __('<p class="description"> This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options. </p>', 'roofers'),
            'icon' => 'el el-paper-clip',
            // Leave this as a blank section, no options just some intro text set above.
            'fields' => array()
        );
        
        return $sections;
    }
}

/**
 * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
 * */
if (!function_exists('change_arguments')) {
    function change_arguments($args)
    {
        //$args['dev_mode'] = true;
        
        return $args;
    }
}

/**
 * Filter hook for filtering the default value of any given field. Very useful in development mode.
 * */
if (!function_exists('change_defaults')) {
    function change_defaults($defaults)
    {
        $defaults['str_replace'] = 'Testing filter hook!';
        
        return $defaults;
    }
}

/**
 * Removes the demo link and the notice of integrated demo from the redux-framework plugin
 */
if (!function_exists('remove_demo')) {
    function remove_demo()
    {
        // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
        if (class_exists('ReduxFrameworkPlugin')) {
            remove_filter('plugin_row_meta', array(
                ReduxFrameworkPlugin::instance(),
                'plugin_metalinks'
            ), null, 2);
            
            // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
            remove_action('admin_notices', array(
                ReduxFrameworkPlugin::instance(),
                'admin_notices'
            ));
        }
    }
}

function newIconFont() {
    // Uncomment this to remove elusive icon from the panel completely
    //wp_deregister_style( 'redux-elusive-icon' );
    //wp_deregister_style( 'redux-elusive-icon-ie7' );
 
    wp_register_style(
        'redux-font-awesome', ROOFERS_THEMEROOT . '/fonts/font-awesome/css/font-awesome.min.css',
        array(),
        time(),
        'all'
    );  
    wp_enqueue_style( 'redux-font-awesome' );
}
// This example assumes the opt_name is set to redux_demo.  Please replace it with your opt_name value.
add_action( 'redux/page/redux_demo/enqueue', 'newIconFont' );
